createEmptyInstance method
Creates an empty instance of the same message type as this.
Implementation
HealthRequest createEmptyInstance() => create();
Creates an empty instance of the same message type as this.
HealthRequest createEmptyInstance() => create();