createEmptyInstance method
Creates an empty instance of the same message type as this.
Implementation
DeviceEvent_Initiater createEmptyInstance() => create();
Creates an empty instance of the same message type as this.
DeviceEvent_Initiater createEmptyInstance() => create();