createEmptyInstance method
Creates an empty instance of the same message type as this.
Implementation
HardwareIdentityInfo createEmptyInstance() => create();
Creates an empty instance of the same message type as this.
HardwareIdentityInfo createEmptyInstance() => create();