createEmptyInstance method
Creates an empty instance of the same message type as this.
Implementation
JobConfig createEmptyInstance() => create();
Creates an empty instance of the same message type as this.
JobConfig createEmptyInstance() => create();