createEmptyInstance method
Creates an empty instance of the same message type as this.
Implementation
Publisher createEmptyInstance() => create();
Creates an empty instance of the same message type as this.
Publisher createEmptyInstance() => create();